pub struct TokenEntry {
pub token: Pubkey,
pub amount: u64,
}Fields
token: Pubkeyamount: u64Trait Implementations
Sourceimpl BorshDeserialize for TokenEntry
impl BorshDeserialize for TokenEntry
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for TokenEntry
impl BorshSerialize for TokenEntry
Sourceimpl Clone for TokenEntry
impl Clone for TokenEntry
Sourcefn clone(&self) -> TokenEntry
fn clone(&self) -> TokenEntry
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TokenEntry
impl Debug for TokenEntry
impl Eq for TokenEntry
Sourceimpl PartialEq for TokenEntry
impl PartialEq for TokenEntry
Sourcefn eq(&self, other: &TokenEntry) -> bool
fn eq(&self, other: &TokenEntry) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for TokenEntry